@@ -2,6 +2,7 @@ from themispy.project.utils import (
     PROJECT_PATH,
     PROJECT_TITLE,
     build_path,
+    split_ospath,
     split_filepath,
     get_logpath
 )
@@ -11,6 +12,7 @@ __all__ = [
     "PROJECT_PATH",
     "PROJECT_TITLE",
     "build_path",
+    "split_ospath"
     "split_filepath",
     "get_logpath"
 ]
